Address class

Implementers

Constructors

Address({required String city, required String citySubdivision, required String street, required String building, String? plotIdentification, required String postalZone, String countryCode = "SA"})
Address.fromMap(Map<String, dynamic> map)
Creates an Address instance from a Map.
factory

Properties

building String
final
city String
final
citySubdivision String
final
countryCode String
final
hashCode int
The hash code for this object.
no setterinherited
plotIdentification String
final
postalZone String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
street String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts the Address instance to a Map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited